# Copyright 2023-2024 by Advanced Technology Systems, LLC.
#
# Unless required by applicable law or agreed to in writing, this software is provided on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND.
#
# Licensed by Advanced Technology Systems, LLC.  The full license is available at:
# http://advtechnologysystems.com/license

import boto3
import json

from argparse import ArgumentParser


class APIGatewayModelCreator(object):

    def __init__(self, api_id, model_dictionary):
        self._api_id = api_id
        self._model_dictionary = model_dictionary
        self._client = boto3.client("apigateway")

    def close(self):

        self._client.close()

    def create_model(self):

        r = self._client.create_model(restApiId=self._api_id, name=self._model_dictionary["title"],
                                      schema=json.dumps(self._model_dictionary).strip(),
                                      contentType="application/json")

        return r


if __name__ == "__main__":

    api_client = None

    try:
        parser = ArgumentParser()

        parser.add_argument("--api-id", action="store", dest="api_id", required=True,
                            help="the id of the API")
        parser.add_argument("--file", action="store", dest="file_name", required=True,
                            help="the name of the JSON method document")

        args = parser.parse_args()

        with open(args.file_name) as model_file:
            model_dict = json.loads(model_file.read())

        api_client = APIGatewayModelCreator(args.api_id, model_dict)
        response = api_client.create_model()

        print("Model named \"{}\" created with id {}".format(response["name"], response["id"]))

        exit(0)

    except Exception as e:
        print(e)
        exit(-1)
    finally:
        if api_client is not None:
            api_client.close()
