# Copyright 2023-2024 by Advanced Technology Systems, LLC.
#
# Unless required by applicable law or agreed to in writing, this software is provided on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND.
#
# Licensed by Advanced Technology Systems, LLC.  The full license is available at:
# http://advtechnologysystems.com/license

import boto3

from argparse import ArgumentParser


class APIGatewayPathCreator(object):

    def __init__(self, api_id, parent_id, path_text):
        self._api_id = api_id
        self._parent_id = parent_id
        self._path_text = path_text
        self._client = boto3.client("apigateway")

    def close(self):

        self._client.close()

    def create_path(self):

        r = self._client.create_resource(restApiId=self._api_id, parentId=self._parent_id, pathPart=self._path_text)

        return r


if __name__ == "__main__":

    api_client = None

    try:
        parser = ArgumentParser()

        parser.add_argument("--api-id", action="store", dest="api_id", required=True,
                            help="the id of the API")
        parser.add_argument("--parent-id", action="store", dest="parent_id", required=True,
                            help="the id of the parent resource (may be root)")
        parser.add_argument("--path-text", action="store", dest="path_text", required=True,
                            help="the text to display for the path to create")

        args = parser.parse_args()

        api_client = APIGatewayPathCreator(args.api_id, args.parent_id, args.path_text)
        response = api_client.create_path()

        print("The path \"{}\" was created with resource id {}".format(response["path"], response["id"]))

        exit(0)

    except Exception as e:
        print(e)
        exit(-1)
    finally:
        if api_client is not None:
            api_client.close()
