# Copyright 2023-2024 by Advanced Technology Systems, LLC.
#
# Unless required by applicable law or agreed to in writing, this software is provided on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND.
#
# Licensed by Advanced Technology Systems, LLC.  The full license is available at:
# http://advtechnologysystems.com/license

import boto3
import json

from argparse import ArgumentParser


class APIGatewayShellCreator(object):

    def __init__(self, api_dictionary):
        self._api_dictionary = api_dictionary
        self._client = boto3.client("apigateway")

    def close(self):

        self._client.close()

    def create_rest_api_shell(self):

        endpoint_cfg_dict = {"types": [self._api_dictionary["EndpointType"]]}
        if "vpcIDList" in self._api_dictionary.keys():
            endpoint_cfg_dict["vpcEndpointIds"] = self._api_dictionary["vpcIDList"]

        if "Tags" in self._api_dictionary.keys():
            if "MinCompressionSize" in self._api_dictionary.keys():
                r = self._client.create_rest_api(name=self._api_dictionary["APIName"],
                                                 apiKeySource=self._api_dictionary["KeySource"],
                                                 minimumCompressionSize=self._api_dictionary["MinCompressionSize"],
                                                 endpointConfiguration=endpoint_cfg_dict,
                                                 tags=self._api_dictionary["Tags"])
            else:
                r = self._client.create_rest_api(name=self._api_dictionary["APIName"],
                                                 apiKeySource=self._api_dictionary["KeySource"],
                                                 endpointConfiguration=endpoint_cfg_dict,
                                                 tags=self._api_dictionary["Tags"])
        else:
            if "MinCompressionSize" in self._api_dictionary.keys():
                r = self._client.create_rest_api(name=self._api_dictionary["APIName"],
                                                 apiKeySource=self._api_dictionary["KeySource"],
                                                 minimumCompressionSize=self._api_dictionary["MinCompressionSize"],
                                                 endpointConfiguration=endpoint_cfg_dict)
            else:
                r = self._client.create_rest_api(name=self._api_dictionary["APIName"],
                                                 apiKeySource=self._api_dictionary["KeySource"],
                                                 endpointConfiguration=endpoint_cfg_dict)

        # get the root based on the id (only the root has been created at this point)
        get_res_response = self._client.get_resources(restApiId=r["id"])
        root_identifier = get_res_response["items"][0]["id"]

        return r, root_identifier


if __name__ == "__main__":

    api_client = None

    try:
        parser = ArgumentParser()

        parser.add_argument("--file", action="store", dest="file_name", required=True,
                            help="the name of the JSON method document")

        args = parser.parse_args()

        with open(args.file_name) as api_file:
            api_dict = json.loads(api_file.read())

        api_client = APIGatewayShellCreator(api_dict)
        response, _ = api_client.create_rest_api_shell()

        print("\"{}\" API created with id {}.".format(response["name"], response["id"]))

        exit(0)

    except Exception as e:
        print(e)
        exit(-1)
    finally:
        if api_client is not None:
            api_client.close()
