# Copyright 2023-2024 by Advanced Technology Systems, LLC.
#
# Unless required by applicable law or agreed to in writing, this software is provided on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND.
#
# Licensed by Advanced Technology Systems, LLC.  The full license is available at:
# http://advtechnologysystems.com/license

import boto3
import json

from ats.utils.api.aws_api_utils_parser import AWSAPIUtilsParser


class APIPolicyCreator(object):

    def __init__(self, policy_dictionary):
        self._policy_dictionary = policy_dictionary
        self._client = boto3.client("iam")

    def close(self):

        self._client.close()

    def create_policy(self):

        policy_doc = json.dumps(self._policy_dictionary["PolicyDoc"]).strip()

        if "Description" in self._policy_dictionary.keys():
            r = self._client.create_policy(PolicyName=self._policy_dictionary["Name"],
                                           PolicyDocument=policy_doc,
                                           Description=self._policy_dictionary["Description"])
        else:
            r = self._client.create_policy(PolicyName=self._policy_dictionary["Name"],
                                           PolicyDocument=policy_doc)

        # process tags if they exist
        if "Tags" in self._policy_dictionary.keys():
            tag_dict_list = []
            for tag_dict in self._policy_dictionary["Tags"]:
                tag_dict_list.append(tag_dict)

            if len(tag_dict_list) > 0:
                _ = self._client.tag_policy(PolicyArn=r["Policy"]["Arn"], Tags=tag_dict_list)

        return r


if __name__ == "__main__":

    iam_client = None

    try:
        parser = AWSAPIUtilsParser()
        args = parser.parse_args()

        policy_dict = parser.load_config_dict()
        iam_client = APIPolicyCreator(policy_dict)
        response = iam_client.create_policy()

        print("\"{}\" created in IAM with ARN {}.".format(response["Policy"]["PolicyName"], response["Policy"]["Arn"]))

        exit(0)

    except Exception as e:
        print(e)
        exit(-1)
    finally:
        if iam_client is not None:
            iam_client.close()
