# Copyright 2023-2024 by Advanced Technology Systems, LLC.
#
# Unless required by applicable law or agreed to in writing, this software is provided on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND.
#
# Licensed by Advanced Technology Systems, LLC.  The full license is available at:
# http://advtechnologysystems.com/license

import json

from argparse import ArgumentParser

from ats.utils.standard_aws_config_replacer import StandardAWSConfigReplacer


class AWSAPIUtilsParser(ArgumentParser):

    def __init__(self):
        super(AWSAPIUtilsParser, self).__init__()
        self.add_argument("--acct", action="store", dest="account_number", required=True,
                          help="the AWS account number to use")
        self.add_argument("--region", action="store", dest="aws_region", required=False, default="us-east-1",
                          help="the optional AWS region to use (defaults to \"us-east-1\")")
        self.add_argument("--file", action="store", dest="file_name", required=True,
                          help="the name of the JSON document containing configuration and/or definition")
        self._standard_replacement_list = []
        self._args = None
        self._std_replacer = None

    def load_config_dict(self):

        config_string = self._std_replacer.do_replacements(self._args.file_name)

        return json.loads(config_string)

    def parse_args(self):

        self._args = super().parse_args()

        standard_replacement_list = [self._args.account_number, self._args.aws_region]

        self._std_replacer = StandardAWSConfigReplacer(standard_replacement_list)

        return self._args
